pub enum PagingError {
NoMemory,
NotAligned,
NotMapped,
AlreadyMapped,
MappedToHugePage,
}Expand description
The error type for page table operation failures.
Variants
NoMemory
Cannot allocate memory.
NotAligned
The address is not aligned to the page size.
NotMapped
The mapping is not present.
AlreadyMapped
The mapping is already present.
MappedToHugePage
The page table entry represents a huge page, but the target physical frame is 4K in size.